pub enum ChildBox<'a> {
SuperBox(SuperBox<'a>),
DataBox(DataBox<'a>),
}Expand description
This type represents a single box within a superbox, which may itself be a superbox or or a regular box.
Note that this crate doesn’t parse the content or ascribe
meaning to any type of box other than superbox (jumb) or
description box (jumd).
Variants
Implementations
Sourceimpl<'a> ChildBox<'a>
impl<'a> ChildBox<'a>
Sourcepub fn as_super_box(&'a self) -> Option<&'a SuperBox<'a>>
pub fn as_super_box(&'a self) -> Option<&'a SuperBox<'a>>
If this represents a nested super box, return a reference to that superbox.
Sourcepub fn as_data_box(&'a self) -> Option<&'a DataBox<'a>>
pub fn as_data_box(&'a self) -> Option<&'a DataBox<'a>>
If this represents a nested data box, return a reference to that data box.